@@ -55,13 +55,20 @@ class Device:
         self.latitude = 0
         self.longitude = 0
         self.altitude = 0
-        self.odo = 0
-        self.speed = 0
-        self.street = None
-        self.city = None
-        self.country = None
-        self.last_distance = None
+        self.odo = None
+        self.speed = None
+        self.trip_start_time = None
+        self.trip_start_street = None
+        self.trip_start_city = None
+        self.trip_start_country = None
+        self.trip_distance = None
+        self.trip_end_street = None
+        self.trip_end_city = None
+        self.trip_end_country = None
+        self.trip_end_time = None
+        self.trip_distance = None
         self.last_seen = None
+        self.location_name = None
 
     @property
     def plate_as_id(self):
@@ -91,11 +98,17 @@ class Device:
             "altitude": self.altitude,
             "odo": self.odo,
             "speed": self.speed,
-            "street": self.street,
-            "city": self.city,
-            "country": self.country,
-            "last_distance": self.last_distance,
-            "last_seen": self.last_seen,
+            "trip_start_time": self.trip_start_time,
+            "trip_start_street": self.trip_start_street,
+            "trip_start_city": self.trip_start_city,
+            "trip_start_country": self.trip_start_country,
+            "trip_end_time": self.trip_end_time,
+            "trip_end_street": self.trip_end_street,
+            "trip_end_city": self.trip_end_city,
+            "trip_end_country": self.trip_end_country,
+            "trip_distance": self.trip_distance,
+            "last_seen": self.trip_end_time,
+            "location_name": self.location_name,
         }
 
     def update_from_json(self, data):
@@ -106,10 +119,7 @@ class Device:
         self.make = self.getvalue(data, "brand")
         self.model = self.getvalue(data, "model")
         self.chassisnumber = self.getvalue(data, "chassisNumber")
-        if "startDate" in data:
-            start = datetime.datetime.fromtimestamp(data["startDate"])
-            self.startdate = start.strftime("%Y-%m-%d %H:%M:%S")
-
+        self.startdate = self.converttime(self.getvalue(data, "startDate"))
         self.year = self.getvalue(data, "yearOfManufacture")
         self.remarks = self.getvalue(data, "remarks")
         self.odo = self.get_odometer(self.identifier)
@@ -125,13 +135,19 @@ class Device:
                 self.longitude = float(location[-1]["lon"] / 1000000)
                 self.speed = location[-1]["speed"]
 
-            self.street = self.getvalue(trip[-1], "endRoad")
-            self.city = self.getvalue(trip[-1], "endCity")
-            self.country = self.getvalue(trip[-1], "endCountry")
-            self.last_distance = self.getvalue(trip[-1], "distance") / 1000
-            if "endDate" in trip[-1]:
-                when = datetime.datetime.fromtimestamp(trip[-1]["endDate"])
-                self.last_seen = when.strftime("%Y-%m-%d %H:%M:%S")
+            self.trip_start_time = self.getvalue(trip[-1], "startDate")
+            self.trip_start_street = self.getvalue(trip[-1], "startRoad")
+            self.trip_start_city = self.getvalue(trip[-1], "startCity")
+            self.trip_start_country = self.getvalue(trip[-1], "startCountry")
+
+            self.trip_end_time = self.getvalue(trip[-1], "endDate")
+            self.trip_end_street = self.getvalue(trip[-1], "endRoad")
+            self.trip_end_city = self.getvalue(trip[-1], "endCity")
+            self.trip_end_country = self.getvalue(trip[-1], "endCountry")
+
+            self.trip_distance = self.getvalue(trip[-1], "distance") / 1000
+            self.trip_end_time = self.converttime(self.getvalue(trip[-1], "endDate"))
+            self.location_name = self.getvalue(trip[-1], "endAlias")
 
     @staticmethod
     def getvalue(data, value):
@@ -140,6 +156,15 @@ class Device:
             return data[value]
         return None
 
+    @staticmethod
+    def converttime(stamp):
+        """Convert datestamp."""
+        if not stamp:
+            return stamp
+
+        when = datetime.datetime.fromtimestamp(stamp)
+        return when.strftime("%Y-%m-%d %H:%M:%S")
+
     def get_odometer(self, object_id: str) -> dict:
         """Get odometer readings."""
 
